@@ -15,6 +15,40 @@ def generate_pairs_trading_simple_corrle(look_backs, keep_same_position_periods_
                         'suffixes' : suffixes})
     return parameters
 
+def generate_pair_trading_shifted_correlation(look_backs, correlation_ranges, keep_same_position_periods_list, suffixes_list):
+    parameters = []
+    for look_back in look_backs:
+        for correlation_range in correlation_ranges:
+            for suffixes in suffixes_list:
+                for keep_same_position_periods in keep_same_position_periods_list:
+                    if look_back > correlation_range:
+                        parameters.append({
+                            'lookback_window': look_back,
+                            'correlation_range' : correlation_range,
+                            'keep_same_position_periods': keep_same_position_periods,
+                            'suffixes': suffixes})
+    return parameters
+
+def pair_trading_shifted_correlation_with_cointegration(look_backs, correlation_ranges, keep_same_position_periods_list, risk_list, alpha_list, suffixes_list):
+    parameters = []
+    for look_back in look_backs:
+        for correlation_range in correlation_ranges:
+            for suffixes in suffixes_list:
+                for keep_same_position_periods in keep_same_position_periods_list:
+                    for risk in risk_list:
+                        for alpha in alpha_list:
+                            if look_back > correlation_range:
+                                parameters.append({
+                                    'lookback_window': look_back,
+                                    'correlation_range' : correlation_range,
+                                    'keep_same_position_periods': keep_same_position_periods,
+                                    'suffixes': suffixes,
+                                    'risk': risk,
+                                    'alpha': alpha})
+    return parameters
+
+
+
 def generate_pairs_trading_log_simple_baseline_parameters(look_backs, keep_same_position_periods_list, percent_deviations, risk_list, alpha_list, suffixes_list):
     parameters = []
     for look_back in look_backs:
