@@ -34,10 +34,44 @@ def pairs_trading_simple_correlation(pair_df = None, correlation_threshold = 0.2
     else:
         np.nan,np.nan
 
-
-
     return None
 
+
+def pair_trading_shifted_correlation(pair_df = None, correlation_range = 100, suffixes=('_btc', '_eth'), **kwargs):
+    len_histo = len(pair_df)
+    assert len_histo > correlation_range
+    return_pair_df = cointegration_utilities.add_returns(pair_df, suffixes=suffixes)
+    correlation_dico = {}
+    for shift in range(correlation_range):
+        shifted_df = return_pair_df.shift(shift).copy()
+        shifted_df['return' + suffixes[1]] = return_pair_df['return'+suffixes[1]].shift(shift)
+        correlation_dico[shift] = shifted_df[['return'+suffixes[0], 'return'+suffixes[1]]].corr().values[0][1]
+    lag = max(correlation_dico, key=correlation_dico.get)
+    signal = return_pair_df['return'+suffixes[1]].values[-lag]
+    return -np.sign(signal), np.sign(signal)
+
+def pair_trading_shifted_correlation_with_cointegration(pair_df = None, correlation_range = 100, risk = 10, alpha = 0.05, suffixes=('_btc', '_eth'), **kwargs):
+    len_histo = len(pair_df)
+    assert len_histo > correlation_range
+    log_returns_df = cointegration_utilities.add_log_returns(pair_df, suffixes=suffixes)
+    log_returns_df = cointegration_utilities.compute_log_return_regressor(log_returns_df, suffixes=suffixes)
+    return_pair_df = cointegration_utilities.add_returns(log_returns_df, suffixes=suffixes)
+    coint_test, alpha, z = cointegration_utilities.apply_cointegration_test(return_pair_df, risk=risk, alpha=alpha,
+                                                                            suffixes=suffixes)
+    if not coint_test:
+        correlation_dico = {}
+        for shift in range(correlation_range):
+            shifted_df = return_pair_df.shift(shift).copy()
+            shifted_df['return' + suffixes[1]] = return_pair_df['return'+suffixes[1]].shift(shift)
+            correlation_dico[shift] = shifted_df[['return'+suffixes[0], 'return'+suffixes[1]]].corr().values[0][1]
+        lag = max(correlation_dico, key=correlation_dico.get)
+        signal = return_pair_df['return'+suffixes[1]].values[-lag]
+        return -np.sign(signal), np.sign(signal)
+
+    else:
+        return np.nan,np.nan
+
+
 def pairs_trading_log_simple_baseline_a(pair_df=None, percent_deviation = 0.1, risk = 10, alpha = 0.05, suffixes=('_btc', '_eth'), log_regressor_kind='log_x_over_log_y', **kwargs):
     log_returns_df = cointegration_utilities.add_log_returns(pair_df, suffixes=suffixes)
     log_returns_df = cointegration_utilities.compute_log_return_regressor(log_returns_df, suffixes=suffixes)
