@@ -464,11 +464,9 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print(aggregated_df.shape)
         return aggregated_df
 
-    def get_aws_last_past_days(self, nb_last_days = 1):
-        date_now = datetime.utcnow()
+    def get_aws_last_past_days(self, running_date, nb_last_days = 1):
         files_to_fetch = []
-
-        d = date_now
+        d = running_date
         for i in range(nb_last_days):
             d = d - timedelta(days=1)
             day_name = self.pair + '_' + d.strftime('%d_%b_%Y') + '_dayohlc'
@@ -887,7 +885,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
             self.day_np = day_df.values
             self.day_df = day_df
         else:
-            updated_df =self.get_aws_last_past_days()
+            updated_df =self.get_aws_last_past_days(running_date)
             updated_df['date'] = pd.to_datetime(updated_df.index)
             updated_df['ts'] = updated_df['date'].values.astype(np.int64) // 10 ** 9
             updated_df = updated_df[updated_df.index <= running_date]
