@@ -13,6 +13,8 @@ import os
 from napoleontoolbox.file_saver import dropbox_file_saver
 import time
 
+from napoleontoolbox.bot import binance_bot
+
 # CryptoCompare
 
 sleeping_time = 0.5
@@ -93,6 +95,12 @@ class CryptoCompare:
         output = output.set_index('timestamp', drop=True).sort_index().drop_duplicates()
         return output
 
+
+def binance_get_histo_balance(api, p, request_date):
+    bot = binance_bot.NaPoleonBinanceFutureBot(api, p)
+    return bot.get_balance_snapshot(request_date)
+
+
 def binance_get(api, p, type_, start_time, end_time = None, symbol = None, aggreg = None):
   '''
   Accepted types: futures_funding, all_futures_orders, futures_klines (aggreg = 1H), spot_klines (aggreg = '1m', '1h')
@@ -381,189 +389,6 @@ def numba_compute_fees(arr, d):
 
 
 
-def recompute_all(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './'):
-    dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=dropbox_token, dropbox_backup=True)
-
-    start_time_stub = start_time.strftime('%d_%b_%Y')
-    end_time_stub = end_time.strftime('%d_%b_%Y')
-    filename_stub = f'{public_key}_{start_time_stub}_{end_time_stub}_Binance'
-    #filename_stub = f'{inv_year_dictionary[year]}_{inv_month_dictionary[month]}_{inv_market_dictionary[market]}'
-
-    report_pkl_file_name = f'{filename_stub}_report.pkl'
-
-    trade_pkl_file_name = f'{filename_stub}_trades.pkl'
-    ohlc_eth_binance_pkl_file_name = f'{filename_stub}_ohlc_eth_binance.pkl'
-    ohlc_btc_binance_pkl_file_name = f'{filename_stub}_ohlc_btc_binance.pkl'
-    walletHist_pkl_file_name = f'{filename_stub}_walletHist.pkl'
-    ohlc_bnb_min_binance_pkl_file_name = f'{filename_stub}_ohlc_bnb_min_binance.pkl'
-    ohlc_btc_cc_pkl_file_name = f'{filename_stub}_ohlc_btc_cc.pkl'
-    ohlc_eth_cc_pkl_file_name = f'{filename_stub}_ohlc_eth_cc.pkl'
-
-
-    print(f'loading {trade_pkl_file_name}')
-    trades = dbx.download_pkl(trade_pkl_file_name)
-    ohlc_eth_binance = dbx.download_pkl(ohlc_eth_binance_pkl_file_name)
-
-    ohlc_btc_binance = dbx.download_pkl(ohlc_btc_binance_pkl_file_name)
-    walletHist = dbx.download_pkl(walletHist_pkl_file_name)
-
-    ohlc_bnb_min_binance = dbx.download_pkl(ohlc_bnb_min_binance_pkl_file_name)
-    ohlc_btc_cc = dbx.download_pkl(ohlc_btc_cc_pkl_file_name)
-    ohlc_eth_cc = dbx.download_pkl(ohlc_eth_cc_pkl_file_name)
-
-# ohlc_eth_binance
-    ohlc_eth_binance = ohlc_eth_binance.set_index('ts')
-    assert isinstance(ohlc_eth_binance.index, pd.DatetimeIndex)
-    ohlc_eth_binance.columns = [x + '_eth_bnc' for x in ohlc_eth_binance.columns]
-    ohlc_eth_binance.index = ohlc_eth_binance.index.tz_localize(None)
-
-    # ohlc_btc_binance
-    ohlc_btc_binance = ohlc_btc_binance.set_index('ts')
-    assert isinstance(ohlc_btc_binance.index, pd.DatetimeIndex)
-    ohlc_btc_binance.columns = [x + '_btc_bnc' for x in ohlc_btc_binance.columns]
-    ohlc_btc_binance.index = ohlc_btc_binance.index.tz_localize(None)
-
-    # ohlc_bnb_binance (minutes)
-    ohlc_bnb_min_binance = ohlc_bnb_min_binance.set_index('ts')
-    assert isinstance(ohlc_bnb_min_binance.index, pd.DatetimeIndex)
-    ohlc_bnb_min_binance.columns = [x + '_bnb_bnc' for x in ohlc_bnb_min_binance.columns]
-    ohlc_bnb_min_binance.index = ohlc_bnb_min_binance.index.tz_localize(None)
-
-    # ohlc_btc_cc
-    x = ohlc_btc_cc
-    x.index = x.index.map(parser.parse)
-    x.index = x.index.tz_localize(None)
-    x.columns = [y + '_btc_cc' for y in x.columns]
-    ohlc_btc_cc = x
-
-    # ohlc_eth_cc
-    x = ohlc_eth_cc
-    x.index = x.index.map(parser.parse)
-    x.index = x.index.tz_localize(None)
-    x.columns = [y + '_eth_cc' for y in x.columns]
-    ohlc_eth_cc = x
-
-    ohlc_eth_cc = ohlc_eth_cc.sort_index(ascending=True).drop_duplicates()
-    ohlc_btc_cc = ohlc_btc_cc.sort_index(ascending=True).drop_duplicates()
-    ohlc_bnb_min_binance = ohlc_bnb_min_binance.sort_index(ascending=True).drop_duplicates()
-    ohlc_btc_binance = ohlc_btc_binance.sort_index(ascending=True).drop_duplicates()
-    ohlc_eth_binance = ohlc_eth_binance.sort_index(ascending=True).drop_duplicates()
-
-    # pd.DataFrame(client.transfer_history(asset = 'USDT', startTime = '870')['rows'])
-    ## 1: transfer from spot main account to future account 2: transfer from future account to spot main account
-    '''ohlc_btc_binance = ohlc_btc_binance.rename_axis('timestamp')
-    ohlc_btc_binance.columns = ['time', 'open', 'high', 'low', 'close', 'volume', 'close_time', 'quote_asset', 'ntrades', 'bavol', 'tbvol', 'ignore'] 
-    ohlc_btc_binance.to_pickle('BNC_BTCm_20200401.p')'''
-
-    #############################################
-    #############################################
-    ######### computing slippage
-    #############################################
-    #############################################
-    # Split
-    import time
-    start = time.time()
-    arr, d = trades_to_arr(trades)
-    df, d = numba_compute(arr, d)
-    print('Done for', trades.shape[0], 'trades in ', time.time() - start, 'seconds.')
-
-    # Work on trades
-    df = pd.DataFrame(df, columns=[i for i in d.keys()])
-    df.time = df.time.apply(lambda x: dt.datetime.utcfromtimestamp(x / 1000))
-    df['dt_floor'] = df.time.dt.floor('H')
-    td = df[['traded_xbt', 'traded_eth', 'size_xbt', 'size_eth', 'sens_trade_xbt', 'sens_trade_eth', 'markets_BTC',
-             'markets_ETH', 'dt_floor']].groupby('dt_floor').sum()
-    td.index = td.index.tz_localize(None)
-    td['avg_eth_price'] = td.size_eth / abs(td.traded_eth)
-    td['avg_btc_price'] = td.size_xbt / abs(td.traded_xbt)
-
-    # Join & compute prices for Binance
-    td = td.join(ohlc_eth_binance['open_eth_bnc'].astype(float)).join(ohlc_btc_binance['open_btc_bnc'].astype(float))
-    td['slippage_eth_price_bnc'] = (td.avg_eth_price / td.open_eth_bnc - 1) * np.sign(td.sens_trade_eth)
-    ## @todo : check here that this is correct
-    td['slippage_eth_cash_bnc'] = td.slippage_eth_price_bnc * abs(
-        td.traded_eth)  # / 1000000 * td.open_btc_bnc * td.open_eth_bnc
-    td['slippage_btc_price_bnc'] = (td.avg_btc_price / td.open_btc_bnc - 1) * np.sign(td.sens_trade_xbt)
-    td['slippage_btc_cash_bnc'] = td.slippage_btc_price_bnc * abs(td.traded_xbt)
-    # slippage en 100e de millionnième de eth = ratio * cours open * qty * 100
-    # slippage en 100e de millionnième de btc = ratio * 1Mo/ cours * 100 * qty
-
-    # Join & compute prices for cryptocompare
-    td = td.join(ohlc_eth_cc['open_eth_cc'].astype(float)).join(ohlc_btc_cc['open_btc_cc'].astype(float))
-    td['slippage_eth_price_cc'] = (td.avg_eth_price / td.open_eth_cc - 1) * np.sign(td.sens_trade_eth)
-    ## @todo : check here that this is correct
-    td['slippage_eth_cash_cc'] = td.slippage_eth_price_cc * abs(
-        td.traded_eth)  # / 1000000 * td.open_btc_cc * td.open_eth_cc
-    td['slippage_btc_price_cc'] = (td.avg_btc_price / td.open_btc_cc - 1) * np.sign(td.sens_trade_xbt)
-    td['slippage_btc_cash_cc'] = td.slippage_btc_price_cc * abs(td.traded_xbt)
-
-    #############################################
-    #############################################
-    ######### computing fees
-    #############################################
-    #############################################
-
-    # walletHist = binance_get('wallet_history',  start_time, end_time= end_time, symbol = 'ETHUSDT')
-    wh, e = wh_to_arr(walletHist)
-    wh, e = numba_compute_fees(wh, e)
-    wh = pd.DataFrame(wh, columns=[i for i in e.keys()])
-    wh.time = wh.time.apply(lambda x: dt.datetime.utcfromtimestamp(x / 1000))
-    wh['dt_floor'] = wh.time.dt.floor('60S')
-    wh = wh.groupby('dt_floor').sum()
-    wh = wh.join(ohlc_bnb_min_binance[['open_bnb_bnc']].astype(float))
-    wh['funding_fees_eth_usd'] = wh.funding_fees_eth
-    wh['funding_fees_xbt_usd'] = wh.funding_fees_xbt
-
-    wh['trading_fees_eth_usd'] = wh['trading_fees_eth'] * wh.open_bnb_bnc + wh.trading_fees_eth_usd
-    wh['trading_fees_xbt_usd'] = wh['trading_fees_xbt'] * wh.open_bnb_bnc + wh.trading_fees_xbt_usd
-    wh['transfers_usd'] = wh.transfers_au + wh.transfers_bnb * wh.open_bnb_bnc
-    wh['dt_floor_h'] = wh.index.map(lambda x: x.floor('H'))
-    wh = wh.groupby('dt_floor_h').sum()
-
-    initial_pnl = wh.at[wh.index[0], 'realized_pnl']
-    starting_value = 10000
-    wh.at[wh.index[0], 'realized_pnl'] = initial_pnl + starting_value  # qqlq k en mars
-
-    wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
-    wh['valuation'] = wh.net_profit + wh.transfers_usd
-    wh['valuation'] = wh.valuation.cumsum()
-    td = td.join(wh.iloc[:, 4:])
-    td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
-    td['amount_traded_usd_btc'] = td.traded_xbt * td.avg_btc_price
-
-    x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'trading_fees_eth_usd',
-            'funding_fees_eth_usd', 'open_eth_cc', 'open_eth_bnc',
-            'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'trading_fees_xbt_usd',
-            'funding_fees_xbt_usd', 'open_btc_cc', 'open_btc_bnc',
-            'valuation',
-            'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
-            'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
-            'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-            'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']]
-
-    x = x.rename_axis('timestamp')
-    x.columns = ['quantity_traded_eth', 'avg_traded_price_eth', 'amount_traded_usd_eth', 'n_trades_eth',
-                 'trading_fees_usd_eth', 'funding_fees_usd_eth',
-                 'open_eth_cc', 'open_eth_exchange',
-                 'quantity_traded_btc', 'avg_traded_price_btc', 'amount_traded_usd_btc', 'n_trades_btc',
-                 'trading_fees_usd_btc', 'funding_fees_usd_btc',
-                 'open_btc_cc', 'open_btc_exchange',
-                 'wallet_amount_usd',
-                 'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_cc', 'slippage_eth_cash_cc',
-                 'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_cc', 'slippage_btc_cash_cc',
-                 'trading_fees_usd_eth', 'funding_fees_usd_eth', 'slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
-                 'trading_fees_usd_btc', 'funding_fees_usd_btc', 'slippage_btc_price_bnc', 'slippage_btc_cash_bnc']
-
-    x = x.fillna(0).round(decimals=5)
-
-    full_path = local_root_directory + report_pkl_file_name
-    x.to_pickle(full_path)
-    print(f'uploading to dropbox {full_path}')
-    dbx.upload(fullname=full_path, folder='', subfolder='', name=report_pkl_file_name, overwrite=True)
-    os.remove(full_path)
-    return x
-
-
 def fetch_all_necessary_data(public_key = None, private_key= None, start_time= None, end_time= None, save_to_dropbox = False, dropbox_token = None, local_root_directory = './'):
     dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=dropbox_token, dropbox_backup=True)
 
@@ -581,16 +406,32 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     ohlc_bnb_min_binance_pkl_file_name = f'{filename_stub}_ohlc_bnb_min_binance.pkl'
     ohlc_btc_cc_pkl_file_name = f'{filename_stub}_ohlc_btc_cc.pkl'
     ohlc_eth_cc_pkl_file_name = f'{filename_stub}_ohlc_eth_cc.pkl'
+    balance_pkl_file_name = f'{filename_stub}_balance.pkl'
 
 
+    initial_balances = binance_get_histo_balance(public_key, private_key, start_time)
 
+    ohlc_bnb_min_binance = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time, symbol ='BNBUSDT', aggreg ='1m')
 
+    initial_bnb_balance = 0
+    initial_usdt_balance = 0
+    try:
+        initial_bnb_balance = initial_balances[initial_balances['asset'] == 'BNB']['walletBalance'][0]
+    except Exception as e:
+        print(e)
+    try:
+        initial_usdt_balance = initial_balances[initial_balances['asset'] == 'USDT']['walletBalance'][0]
+    except Exception as e:
+        print(e)
+
+    initial_usd_balance = initial_usdt_balance + initial_bnb_balance * ohlc_bnb_min_binance.iloc[start_time]
+    print(initial_usd_balance)
 
     trades = binance_get(public_key, private_key, 'trade_history', start_time, end_time=end_time, symbol ='ETHUSDT').drop_duplicates()
     ohlc_eth_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='ETHUSDT', aggreg ='1m')
     ohlc_btc_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='BTCUSDT', aggreg ='1m')
     walletHist = binance_get(public_key, private_key, 'wallet_history', start_time, end_time= end_time, symbol ='ETHUSDT')
-    ohlc_bnb_min_binance = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time, symbol ='BNBUSDT', aggreg ='1m')
+
 
     # Get datacryptocompare
     cc = CryptoCompare('afb994efa0ca3fc08f6b4b4b1ce74d3cfdfbf962b4c2e6fe4a5694dd37cd68aa')
@@ -601,6 +442,12 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     print("OHLC Cryptocompare retrieved.")
 
     if save_to_dropbox :
+        full_path = local_root_directory + balance_pkl_file_name
+        initial_balances.to_pickle(full_path)
+        print(f'uploading to dropbox {full_path}')
+        dbx.upload(fullname=full_path, folder='', subfolder='', name=balance_pkl_file_name, overwrite=True)
+        os.remove(full_path)
+
         full_path = local_root_directory + trade_pkl_file_name
         trades.to_pickle(full_path)
         print(f'uploading to dropbox {full_path}')
